@@ -13,7 +13,14 @@ from inflection import humanize
 from importlib import import_module
 from .auto_docs import mod_doc
 
-
+try:
+    # *IF* we are in a project based on devapps, we can build call flow logs also
+    # from pytest, not just from docs/lp. Requirements are these imports:
+    from devapp.tools import FLG, exists, project, write_file, read_file
+    from devapp.tools import define_flags, project, to_list
+    from absl.flags._exceptions import UnparsedFlagAccessError
+except:
+    pass
 # ------------------------------------------------------------------------------ tools
 now = time.time
 
@@ -301,6 +308,7 @@ def document(
     call_seq_closed=True,
     flags=None,
     dest=None,
+    wait_before=0,
 ):
     """
     Decorating call flow triggering functions (usually pytest functions) with this
@@ -363,6 +371,8 @@ def document(
                 for k, v in flags.items():
                     flg[k] = v() if callable(v) else v
                 set_flags(flg)
+            ##if wait_before:
+            #    time.sleep(wait_before)
             try:
                 throw = None
                 # set_flags(flags)
@@ -546,8 +556,10 @@ def add_flow_json_and_graph_easy_links(fn, T):
             l = T.closed_admon('Flow Json', p + T.code('js', s), 'info')
             # os.unlink(fn) # will be analysed by ops refs doc page
         s = f.replace(ext, '')
-        dl = d.rsplit('/', 1)[-1]
-        r = '\n\n![](./%s/%s.svg)\n\n' % (dl, s)
+        parts = d.rsplit('/', 2)
+        test = parts[-2]
+        dl = parts[-1]
+        r = '\n\n![](./%s/%s/%s.svg)\n\n' % (test, dl, s)
         # when s = 'test_build.py::Sharing::test_share_deep_copy.tests.post_build.svg'
         # then n = 'tests.post_build':
         if l:
